--
-- Specialization AnimDoors
--
-- @author  	Aluha74rus
-- @version 	v1.0
-- @date  		15/02/20

AnimDoors = {};
local AnimDoors_directory = g_currentModDirectory;


function AnimDoors.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations) 
end;

function AnimDoors.registerEventListeners(vehicleType)	
	SpecializationUtil.registerEventListener(vehicleType, "onLoad", AnimDoors);
	SpecializationUtil.registerEventListener(vehicleType, "onUpdate", AnimDoors)
	SpecializationUtil.registerEventListener(vehicleType, "onRegisterActionEvents", AnimDoors)
end

function AnimDoors:onRegisterActionEvents(isSelected, isActiveForInput)
	if isActiveForInput then
		if self.AnimDoors == nil then 
			self.AnimDoors = {}
		else	
			self:clearActionEventsTable( self.AnimDoors )
		end 
		for _,actionName in pairs({ "AXIS_LEFT_DOOR"} ) do
			local _, eventName = self:addActionEvent(self.AnimDoors, InputAction[actionName], self, AnimDoors.actionDoors, true, true, false, true, nil);
			if isSelected then
				g_inputBinding.events[eventName].displayPriority = 1
			elseif  isActiveForInput then
				g_inputBinding.events[eventName].displayPriority = 3
			end
		end
	end
end

function AnimDoors.registerFunctions(vehicleType)
    SpecializationUtil.registerFunction(vehicleType, "playAnimDoors",         AnimDoors.playAnimDoors)
end

function AnimDoors:onLoad(savegame)
    self.playerTrigerHood = AnimDoors.playerTrigerHood; 
    self.playerTrigerDoorLeft = AnimDoors.playerTrigerDoorLeft; 
	
    self.animDoors = {};
    local baseString = string.format("vehicle.K744R4.");
	
    if hasXMLProperty(self.xmlFile, "vehicle.K744R4.animDoors") then
		
        self.animDoors.door = {};
        i=0;
        while true do
            self.animDoors.door[i] = getXMLString(self.xmlFile,baseString..string.format("animDoors.door#animName%d", i));
            if self.animDoors.door[i] == nil then
                break;
            end;
            i=i+1;
        end;
    end;
	
    self.hood = {};
	local trigger = I3DUtil.indexToObject( self.components, getXMLString(self.xmlFile, string.format("vehicle.K744R4.triggers.hoodTrigger#trigger")) );
	self.hood.trigger = trigger;
    self.hood.Aktive = false
	addTrigger( trigger, "playerTrigerHood", self );
	
    self.doorLeft = {};
	local trigger = I3DUtil.indexToObject( self.components, getXMLString(self.xmlFile, string.format("vehicle.K744R4.triggers.doorLeftTrigger#trigger")) );
	self.doorLeft.trigger = trigger;
    self.doorLeft.Aktive = false
	addTrigger( trigger, "playerTrigerDoorLeft", self );
	
end;

function AnimDoors:onDelete()
	if self.hood.trigger ~= nil then
		removeTrigger(self.hood.trigger);
	end;
end
function AnimDoors:onUpdate(dt, isActiveForInput, isSelected)
	
    if self.isClient then
	    if self.hood.Aktive then
            self:playAnimDoors(self.animDoors.door[0], 1);
		else
            self:playAnimDoors(self.animDoors.door[0], -1);
	    end;
	    if self.doorLeft.Aktive then
            self:playAnimDoors(self.animDoors.door[1], 1);
		else
            self:playAnimDoors(self.animDoors.door[1], -1);
	    end;
    end
end;
function AnimDoors:playAnimDoors(animName, animSpeed)    
    local animTime = self:getAnimationTime(animName);
    if not self:getIsAnimationPlaying(animName) then    
        self:playAnimation(animName, animSpeed, animTime, true);
    end;
end;

function AnimDoors:actionDoors(actionName, keyStatus, arg4, arg5, arg6)
    if self.isClient then
		if keyStatus > 0 then
			if actionName == 'AXIS_LEFT_DOOR' then
			    self.doorLeft.Aktive = not self.doorLeft.Aktive
			end
		end
    end
end

function AnimDoors:actionHood(actionName, keyStatus, arg4, arg5, arg6)
    if self.isClient then
		if keyStatus > 0 then
			if actionName == 'AXIS_HOOD' then
			    self.hood.Aktive = not self.hood.Aktive
			end
		end
    end
end

function AnimDoors:playerTrigerHood(triggerId, otherId, onEnter, onLeave, onStay)

	if onEnter and g_currentMission.controlPlayer and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
		self:raiseActive()
		self.actionEvents = {}; 
		self:clearActionEventsTable(self.actionEvents); -- 
		local _ , eventId = self:addActionEvent(self.actionEvents, InputAction.AXIS_HOOD, self, AnimDoors.actionHood, false, true, false, true);	-- now add the actionEvent 	
	elseif onLeave and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
		self:removeActionEvent(self.actionEvents, InputAction.AXIS_HOOD);
	end;
end;

function AnimDoors:playerTrigerDoorLeft(triggerId, otherId, onEnter, onLeave, onStay)

	if onEnter and g_currentMission.controlPlayer and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
		self:raiseActive()
		self.actionEvents = {}; 
		self:clearActionEventsTable(self.actionEvents); -- 
		local _ , eventId = self:addActionEvent(self.actionEvents, InputAction.AXIS_LEFT_DOOR, self, AnimDoors.actionDoors, false, true, false, true);	-- now add the actionEvent 	
	elseif onLeave and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
		self:removeActionEvent(self.actionEvents, InputAction.AXIS_LEFT_DOOR);
	end;
end;